@@ -39,7 +39,17 @@ synthetic <- clusterlab(centers=5,r=8,sdvec=c(2.5,2.5,2.5,2.5,2.5),
                         numbervec=c(50,50,50,50,50))
 
 ## ----fig.width=6,fig.height=6--------------------------------------------
-head(synthetic$identity_matrix)
+library(clusterlab)
+synthetic <- clusterlab(centers=5,r=7,sdvec=c(2,2,2,2,2),   
+                        alphas=c(2,2,2,2,2),centralcluster=FALSE,   
+                        numbervec=c(50,50,50,50), seed=123, outliers=10, outlierdist = 20)
+
+## ----fig.width=6,fig.height=6--------------------------------------------
+library(clusterlab)
+synthetic <- clusterlab(centers=5,r=7,sdvec=c(6,6,6,6,6),   
+                        alphas=c(2,2,2,2,2),centralcluster=FALSE,   
+                        numbervec=c(50,50,50,50),rings=5,ringalphas=c(2,4,6,8,10,12),
+                        seed=123) # for a six cluster solution)
 
 ## ----fig.width=6,fig.height=6--------------------------------------------
 library(clusterlab)
@@ -48,3 +58,6 @@ synthetic <- clusterlab(centers=5,r=7,sdvec=c(6,6,6,6,6),
                         numbervec=c(50,50,50,50),rings=5,ringalphas=c(2,4,6,8,10,12), 
                         ringthetas = c(30,90,180,0,0,0), seed=123) # for a six cluster solution)
 
+## ----fig.width=6,fig.height=6--------------------------------------------
+head(synthetic$identity_matrix)
+
